import { Component } from '@tarojs/taro';
import { ComponentClass } from 'react';
import { View, ScrollView, Image, Text } from '@tarojs/components';

import AnnIcon from '../../images/icon/ann_tongzhi_icon@2x.png';
import { fetchAllAnn, AnnItem } from '../../api/announcement';
import { connect } from '@tarojs/redux';
import { UserState } from '../../store/rootReducers/userinfo';

import './Announcement.scss';

type PageStateProps = {
  userinfo: UserState;
};
type PageOwnProps = {};
type PageState = {
  pageNum: number;
  pageSize: number;
  list: AnnItem[];
};

interface Announcement {
  props: PageStateProps & PageOwnProps;
  state: PageState;
}

@connect(({ userinfo }) => ({
  userinfo,
}))
class Announcement extends Component {
  constructor(props) {
    super(props);
    this.state = {
      pageNum: 1,
      pageSize: 10,
      list: [],
    };
  }
  componentWillMount() {
    const { userinfo } = this.props;
    const { sectionId } = this.$router.params;
    fetchAllAnn({
      campusId: userinfo.areaId,
      sectionId: sectionId,
    })
      .then(res => {
        const data = res.data;
        this.setState({
          ...data,
        });
      })
      .catch(err => {
        console.log(err);
        this.setState({
          pageNum: 1,
          pageSize: 10,
          pages: 1,
          total: 2,
          list: [
            {
              id: 301070,
              title: 'ASFDSGSD大苏打',
              multiImageType: 'SINGLE',
              source: '关机开不开地方',
              linkUrls: ['sqwerqwerqwefsf'],
              linkType: 'DEFAULT',
              jumpUrl: '',
              urlParameters: {},
              sort: 1,
              enabled: true,
              loadAd: false,
              mandatoryPrompt: false,
              effectTime: 1529431320000,
              expirationTime: 1530129600000,
              createTime: '2018-06-01 10:41:11',
              updateTime: '2019-01-25 09:43:17',
            },
            {
              id: 301073,
              title: '啊实打实的阿斯顿',
              multiImageType: 'SINGLE',
              source: '个撒大',
              linkUrls: ['sqwerqwerqwefsf'],
              linkType: 'DEFAULT',
              jumpUrl: '',
              urlParameters: {},
              sort: 2,
              enabled: true,
              loadAd: false,
              mandatoryPrompt: false,
              createTime: '2018-06-12 10:52:15',
              updateTime: '2019-01-25 09:47:39',
            },
          ],
        });
      });
  }
  geAnnDetail(id: number) {
    console.log(id);
  }
  render() {
    const { list } = this.state;
    return (
      <ScrollView className='Announcement' scroll-y>
        {list.map(annItem => (
          <View
            key={annItem.id}
            className='Announcement-item'
            onClick={() => this.geAnnDetail(annItem.id)}
          >
            <Image
              className='Announcement-item-img'
              src={annItem.linkUrls[0]}
            />
            <View className='Announcement-item-Content'>
              <Image className='Announcement-item-icon' src={AnnIcon} />
              <Text className='Announcement-item-title'>{annItem.title}</Text>
              <Text className='Announcement-item-date'>
                {annItem.updateTime}
              </Text>
            </View>
          </View>
        ))}
      </ScrollView>
    );
  }
}

export default Announcement as ComponentClass;
