import { ComponentClass } from 'react';
import Taro, { Component, Config } from '@tarojs/taro';
import { View, Text, Image } from '@tarojs/components';

import OrderTitle from '../components/OrderTitle/OrderTitle';
import OrderInfo from '../components/OrderInfo/OrderInfo';
import comLogo from '../../../images/order/pay_logo_icon@2x.png';

import './OrderDetail.scss';
import { fetchOrderDetail, fetchOrderDetailAndPay } from '../../../api/order';
import { PayType, getPayType } from '../../../utils/payType';

type pageProps = {};
type PageState = {
  actualMoney: 0;
  areaId: 0;
  areaName: string;
  consumeType: string;
  createAt: string;
  customerCellphone: string;
  customerId: 0;
  customerName: string;
  deductionBean: 0;
  deductionMoney: 0;
  equipmentNum: string;
  equipmentPosition: string;
  id: 0;
  operateId: 0;
  operateName: string;
  operationMode: string;
  orderName: string;
  orderNumber: string;
  orderState: string;
  outTradeNo: string;
  payType: PayType;
  payableMoney: 0;
  serviceId: 0;
  serviceName: string;
  thirdDiscountMoney: 0;
  thirdTradeNumber: string;
  updateDate: string;
};

interface OrderDetail {
  props: pageProps;
  state: PageState;
}
class OrderDetail extends Component {
  config: Config = {
    navigationBarTitleText: '订单详情',
  };
  constructor(props) {
    super(props);
    this.state = {
      actualMoney: 0,
      areaId: 0,
      areaName: '',
      consumeType: '',
      createAt: '',
      customerCellphone: '',
      customerId: 0,
      customerName: '',
      deductionBean: 0,
      deductionMoney: 0,
      equipmentNum: '',
      equipmentPosition: '',
      id: 0,
      operateId: 0,
      operateName: '',
      operationMode: '',
      orderName: '',
      orderNumber: '',
      orderState: '',
      outTradeNo: '',
      payType: '',
      payableMoney: 0,
      serviceId: 0,
      serviceName: '',
      thirdDiscountMoney: 0,
      thirdTradeNumber: '',
      updateDate: '',
    };
  }

  componentWillMount() {
    console.log('preload: ', this.$router.preload);
    const data = this.$router.preload;
    this.setState({
      ...data,
    });
    // this.getDetailInfo(id);
  }

  getDetailInfo(id: number) {
    return fetchOrderDetailAndPay({
      id: id,
    })
      .then(res => {
        console.log(res);
      })
      .catch(err => {
        console.log(err);
      });
  }
  render() {
    const {
      actualMoney,
      payableMoney,
      deductionBean,
      payType,
      createAt,
      thirdTradeNumber,
      serviceName,
      orderNumber,
      areaName,
      equipmentNum,
      equipmentPosition,
      deductionMoney,
    } = this.state;
    const payTypeName = getPayType(payType);
    return (
      <View className='OrderDetail'>
        <OrderTitle price={payableMoney} />
        <OrderInfo
          serviceName={serviceName}
          createAt={createAt}
          orderNumber={orderNumber}
          areaName={areaName}
          equipmentNum={equipmentNum}
          equipmentPosition={equipmentPosition}
        />
        <View className='OrderDetail-line' />
        <View className='OrderDetail-payinfo'>
          <Text>支付金额</Text>
          <Text>{actualMoney.toFixed(2)}</Text>
        </View>
        {deductionBean ? (
          <View className='OrderDetail-payinfo'>
            <Text>通用豆抵扣</Text>
            <Text>{deductionBean.toFixed(2)}</Text>
          </View>
        ) : null}
        {deductionMoney ? (
          <View className='OrderDetail-payinfo'>
            <Text>艾米抵扣</Text>
            <Text>{deductionMoney.toFixed(2)}</Text>
          </View>
        ) : null}

        <View className='OrderDetail-payinfo'>
          <Text>支付方式</Text>
          <Text>{payTypeName}</Text>
        </View>
        <View className='OrderDetail-payinfo'>
          <Text>支付时间</Text>
          <Text>{createAt}</Text>
        </View>
        {thirdTradeNumber ? (
          <View className='OrderDetail-payinfo'>
            <Text>交易单号</Text>
            <Text>{thirdTradeNumber}</Text>
          </View>
        ) : null}
      </View>
    );
  }
}

export default OrderDetail as ComponentClass<pageProps, PageState>;
