import Taro, { Component } from '@tarojs/taro';
import { ComponentClass } from 'react';
import { Button, View, Image, Text } from '@tarojs/components';
import { UserState } from '../../../../store/rootReducers/userinfo';
import { PaymentAndActiveInfo } from '../../../../api/baseClass';
import { confirmPay } from '../../../../api/order';

import payWayWxLogo from '../../../../images/order/pay_wechat_icon@2x.png';
import payWayAimiLogo from '../../../../images/order/pay_aimi_icon@2x.png';
import payWayHairLogo from '../../../../images/order/pay_chuifengdou_icon@2x.png';
import payWayComLogo from '../../../../images/order/pay_tongyongdou_icon@2x.png';

import './OrderPayway.scss';
import AES from 'crypto-js/aes';
import Utf8 from 'crypto-js/enc-utf8';
import ECBmode from 'crypto-js/mode-ecb';
import PaddingPkcs7 from 'crypto-js/pad-pkcs7';
import { getPayType } from '../../../../utils/payType';

type PageOwnProps = {
  payDoneCallback: () => void;
  userinfo: UserState;
  orderId: number;
  payInfos: {
    paymentAndActiveInfos: PaymentAndActiveInfo[];
    paymentConfId: number;
  };
  deductionInfos: {
    amiAccount: number;
    beanAccount: number;
    deductionMoney: number;
    deductionType: string;
    orderMoney: number;
    payMoney: number;
    payType: string;
    remainAccount: number;
    titlePerfix: string;
  };
};
type PageState = {
  prePay: boolean;
  payWay: null | {
    activeId: number | undefined;
    amount: number | undefined;
    avtiveComment: string;
    deductionValue: number | undefined;
    isDeduction: number | undefined;
    payType: string;
    payVersion: string;
  };
};

interface OrderPayway {
  props: PageOwnProps;
  state: PageState;
}
class OrderPayway extends Component {
  constructor(props) {
    super(props);
    this.state = {
      prePay: true,
      payWay: null,
    };
  }

  changePayWay(payWay: PaymentAndActiveInfo) {
    this.setState({
      payWay: payWay,
    });
  }

  changePayState() {
    const { payWay } = this.state;
    if (payWay) {
      this.setState({
        prePay: false,
      });
    } else {
      Taro.showToast({
        title: '请选择支付方式',
        icon: 'none',
      });
    }
  }

  callNativePay() {
    const {
      userinfo: { customerId },
      orderId,
      payInfos,
      payDoneCallback,
    } = this.props;
    const { payWay } = this.state;
    confirmPay({
      orderId: orderId,
      payType: payWay.payType,
      [payWay.activeId ? 'activeId' : 'notUse']: payWay.activeId,
      returnUrl: '',
      callType: '3',
      paymentConfId: payInfos.paymentConfId,
    })
      .then(res => {
        console.log(res);
        const { payStr } = res;
        if (payStr) {
          const key = customerId.toString().padEnd(16, '0');
          console.log(key);
          const payData = JSON.parse(
            AES.decrypt(payStr, Utf8.parse(key), {
              mode: ECBmode,
              padding: PaddingPkcs7,
            }).toString(Utf8)
          );
          console.log(payData);

          Taro.requestPayment({
            timeStamp: payData.msg.timestamp.toString(),
            nonceStr: payData.msg.noncestr,
            package: payData.msg.package,
            signType: 'MD5',
            paySign: payData.msg.sign,
            success(res) {
              console.log(res);
              payDoneCallback();
            },
            fail(res) {
              Taro.showToast({
                title: res.msg || '发起支付失败',
                icon: 'none',
              });
            },
          });
        } else {
          payDoneCallback();
        }
      })
      .catch(err => {
        console.log(err);

        Taro.showToast({
          title: err.msg || '发起支付失败',
          icon: 'none',
        });
      });
  }
  render() {
    const { prePay, payWay } = this.state;
    const {
      payInfos: { paymentAndActiveInfos },
      deductionInfos,
    } = this.props;
    const payInfoList = paymentAndActiveInfos.filter(
      item =>
        item.payType === '2' ||
        item.payType === '6' ||
        item.payType === '7' ||
        item.payType === '8'
    );
    const payInfo = prePay
      ? null
      : payInfoList.find(item => item.payType === payWay.payType);
    return (
      <View className='OrderPayway'>
        {prePay ? (
          payInfoList.length ? (
            payInfoList.map((payway, index) => (
              <View
                key={index}
                className='OrderPay-payway'
                onClick={() => this.changePayWay(payway)}
              >
                {payway.payType === '2' ? (
                  <Image className='OrderPay-icon' src={payWayWxLogo} />
                ) : payway.payType === '6' ? (
                  <Image className='OrderPay-icon' src={payWayAimiLogo} />
                ) : payway.payType === '7' ? (
                  <Image className='OrderPay-icon' src={payWayHairLogo} />
                ) : payway.payType === '8' ? (
                  <Image className='OrderPay-icon' src={payWayComLogo} />
                ) : null}
                {payway.payType === '2' ? (
                  <Text className='OrderPay-text'>
                    {getPayType(payway.payType)}
                  </Text>
                ) : payway.payType === '6' ? (
                  <Text className='OrderPay-text'>
                    {getPayType(payway.payType)}(余额：
                    {deductionInfos.amiAccount.toFixed(2)})
                  </Text>
                ) : (
                  <Text className='OrderPay-text'>
                    {getPayType(payway.payType)}(余额：
                    {deductionInfos.beanAccount
                      ? deductionInfos.beanAccount.toFixed(2)
                      : '0.00'}
                    )
                  </Text>
                )}

                <View
                  className={`OrderPay-check ${
                    payWay && payWay.payType === payway.payType ? 'checked' : ''
                  }`}
                />
              </View>
            ))
          ) : null
        ) : (
          <View>
            <View className='OrderPay-payinfo'>
              <Text>订单金额</Text>
              <Text>{deductionInfos.payMoney}</Text>
            </View>
            {deductionInfos.deductionType === '1' ? (
              <View>
                <View className='OrderPay-payinfo'>
                  <Text>
                    {deductionInfos.titlePerfix}豆抵扣金额（余额:
                    {deductionInfos.beanAccount.toFixed(2)}）
                  </Text>
                  <Text>{deductionInfos.deductionMoney.toFixed(2)}</Text>
                </View>
                <View className='OrderPay-DeductionInfo'>
                  豆抵扣总消费额的
                  {payWay && payWay.deductionValue
                    ? payWay.deductionValue * 100
                    : 0}
                  %，不满0.01元，累计算1分
                </View>
              </View>
            ) : deductionInfos.deductionType === '2' ? (
              <View>
                <View className='OrderPay-payinfo'>
                  <Text>
                    通用豆抵扣金额（余额:{deductionInfos.beanAccount.toFixed(2)}
                    ）
                  </Text>
                  <Text>{deductionInfos.deductionMoney.toFixed(2)}</Text>
                </View>
                <View className='OrderPay-DeductionInfo'>
                  豆抵扣总消费额的
                  {payWay && payWay.deductionValue
                    ? payWay.deductionValue * 100
                    : 0}
                  %，不满0.01元，累计算1分
                </View>
              </View>
            ) : deductionInfos.deductionType === '3' ? (
              <View className='OrderPay-payinfo'>
                <Text>
                  艾米抵扣金额（余额:{deductionInfos.amiAccount.toFixed(2)}）
                </Text>
                <Text>{deductionInfos.deductionMoney.toFixed(2)}</Text>
              </View>
            ) : null}

            <View className='OrderPay-payinfo'>
              <Text>{payInfo ? payInfo.payTypeName : ''}金额</Text>
              <Text>{deductionInfos.payMoney}</Text>
            </View>
          </View>
        )}
        {prePay ? (
          <Button
            className='button OrderPay-next'
            onClick={this.changePayState}
          >
            下一步
          </Button>
        ) : (
          <Button className='button OrderPay-next' onClick={this.callNativePay}>
            确认支付
          </Button>
        )}
      </View>
    );
  }
}

export default OrderPayway as ComponentClass<PageOwnProps, PageState>;
